@@ -1,4 +1,4 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
 # If you change or add any strings in this file please contact the translators listed below
 # Everything must be in UTF-8
@@ -18,6 +18,7 @@ class ru: # Russian - evadim <evadim@evadim.ru>, Night Nord <NightNord@gmail.com
 	searchnodataform = u"Используйте вложенную форму для поиска.  Если ваш XMPP-клиент не поддерживает Data Forms, использовать поиск будет невозможно."
 	searchtitle = u"Поиск пользователей"
 	searchinstructions = u"Укажите e-mail адресс, или любую другую информацию в соответствующих полях, для поиска подходящих пользователей в базе ICQ.  Если заполнено поле e-mail, все другие поля игнорируются."
+	sessionslimit = u"Извините, вы не можете быть подключены к ICQ из-за того что слишком много сессий активно в данный момент. Попробуйте позже или выберите другой шлюз из списка http://www.jabberes.org/servers/servers_by_gateway_icq.html"
 	command_CommandList = u"Команды PyICQt"
 	command_Statistics = u"Статистика PyICQt"
 	command_RosterRetrieval = u"Получить содержимое контакт-листа"
@@ -114,6 +115,7 @@ class ru: # Russian - evadim <evadim@evadim.ru>, Night Nord <NightNord@gmail.com
 	settings_category_clist = u"Настройки списка контактов"
 	settings_category_message = u"Настройки сообщений"
 	settings_category_personal_events = u"Настройки оповещений"
+	settings_category_autoanswer = u"Автоответчик"
 	settings_instructions = u"Выберите категорию настроек"
 	settings_changed = u"Настройки изменены успешно"
 	settings_instructions_Desc = u"Внимание: Вам нужно переподключиться чтобы настройки отмеченные звёздочкой (*) вступили в силу"
@@ -160,8 +162,8 @@ class ru: # Russian - evadim <evadim@evadim.ru>, Night Nord <NightNord@gmail.com
 	utf8_messages_sendmode_Desc = u"Сообщения в utf-8 позволяют решить проблему с кодировками"
 	offline_messages_sendenc = u"Кодировка для исходящих оффлайн-сообщений"
 	offline_messages_sendenc_unicode = u"Unicode"
-	offline_messages_sendenc_local = u"местная (%s)"
-	offline_messages_sendenc_auto = u"автоопределение"
+	offline_messages_sendenc_local = u"Однобайтовая кодировка"
+	offline_messages_sendenc_auto = u"Автоопределение"
 	offline_messages_sendenc_Desc = u"Рекомендуется автоопределение"
 	msgconfirm_sendmode = u"Режим отправки подтвеждений"
 	msgconfirm_sendmode_none = u"Отправка отключена"
@@ -179,6 +181,16 @@ class ru: # Russian - evadim <evadim@evadim.ru>, Night Nord <NightNord@gmail.com
 	user_activity_receiving_Desc = u"Иконка Х-статуса как занятие - поддерживается в Gajim 0.12+, Jabbim 0.4+, Tkabber 0.11+, Coccinella 0.96+, Miranda IM 0.8+"
 	user_tune_receiving_Desc = u"Иконка Х-статуса как мелодия - поддерживается в Psi 0.11+, Gajim 0.12+, Jabbim 0.4+, Tkabber 0.11+, Miranda IM 0.7+"
 
+	# auto-answer settings
+	autoanswer_enable = u"Включть автоответчик"
+	autoanswer_enable_Desc = u"Выбранный текст будет отправлен в качестве ответа на любое входящее сообщение"
+	autoanswer_hide_dialog =  u"Скрывать диалог автоответчика"
+	autoanswer_hide_dialog_Desc = u"Скрывать входящие сообщения когда автоответчик отвечает на них"
+	autoanswer_text = u"Текст"
+	autoanswer_text_Desc = u"Текст автоответчика"
+	autoanswer_text_content = u"Привет. Я отсутствую и не могу ответить прямо сейчас. Оставьте свое сообщение"
+	autoanswer_prefix = u"[Автоответчик]"
+
 	# additional "normal" statuses
 	anstatus_out_to_lunch = u"Ем"
 	anstatus_on_the_phone = u"Разговариваю по телефону"
