@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2004-2006 Daniel Henninger <jadestorm@nc.rr.com>
 # Licensed for distribution under the GPL version 2, check COPYING for details
 
@@ -26,7 +27,7 @@ from twisted.python import log
 name = "ICQ Transport"
 
 # The transport's version
-version = "0.8.1.3"
+version = "0.8.1.5"
 
 # URL of the transport's web site
 url = "http://pyicqt.googlecode.com/"
@@ -197,12 +198,12 @@ class LegacyConnection:
 					if offline and int(self.bos.settingsOptionValue('offline_messages_sendenc')) == 0: # Unicode for offline messages
 					    charset = 'unicode' # utf-16be
 					elif offline and int(self.bos.settingsOptionValue('offline_messages_sendenc')) == 1: # local encoding for offline messages
-					    charset = 'iso-8859-1' # config encoding
+					    charset = 'custom' # single-byte encoding
 					else: # autodetect (both for offline and online messages)
 					    if self.legacyList.hasCapability(uin, 'unicode'): # contact has unicode cap
 						charset = 'unicode' # utf-16be
 					    else:
-						charset = 'iso-8859-1' # config encoding
+						charset = 'custom' # single-byte encoding
 					self.bos.sendMessage(uin, [[message,charset]], offline=offline, wantIcon=wantIcon, autoResponse=autoResponse, iconSum=iconSum, iconLen=iconLen, iconStamp=iconStamp, cookie=cookie)
 				self.session.sendArchive(target, self.session.jabberID, message)
 			else: # AIM users
